@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1742 2010-10-24 17:03:07Z beerli $
+$Id: data.c 1754 2010-10-29 01:51:00Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -1369,13 +1369,6 @@ read_alleles (FILE * infile, data_fmt * data, long pop, long ind)
     myfree(isave);
 }
 
-#ifdef WINDOWS
-long lround(double d)
-{
-  return floor( d+0.5 );
-}
-#endif
-
 void
 read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,
               long locus, long pop)
@@ -1426,7 +1419,7 @@ read_hapmap (FILE * infile, data_fmt * data, option_fmt * options,
 	//  data->numalleles[pop][locus] = options->randomsubset * genomes;
 	//else
 	data->numalleles[pop][locus] = data->numind[pop][locus] * genomes;
-	label1count = lround(label1count/label12count * data->numalleles[pop][locus]);
+	label1count = floor( ((label1count/label12count * data->numalleles[pop][locus]))+0.5 );
 	label12count = data->numalleles[pop][locus] - label1count;
 	for(ind=0;ind < label1count; ind++)
 	  {
@@ -2270,7 +2263,6 @@ void find_allele_repeatlength(data_fmt *data, option_fmt *options, long locus)
 	      MYREAL floored = floor(nonfloored);
 	      MYREAL diff = nonfloored - floored; 
 	      intval = (long) floored + (RANDUM() < (1.0-diff) ? 0 : 1); 
-	      //	      intval = (long) lround((value + keepr - keepstartvalue)/data->repeatlength[locus]);
 	      sprintf(data->yy[pop][ind][locus][1],"%li",intval);
 	    }
 	}
