@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1713 2010-09-05 03:16:27Z beerli $*/
+/* $Id: main.c 1748 2010-10-25 00:42:42Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -515,13 +515,6 @@ main (int argc, char **argv)
 	// the penalizing of far jumps in the maximizer function
       } // end of printing main tables and histograms
     
-#ifdef NEXUSTREE
-    if (EARTH->options->treeprint == LASTCHAIN)
-      {
-	FPRINTF(EARTH->treefile,"\nend;\n");
-      }
-#endif
-
 #ifdef SLOWNET
     which_calc_like (PROFILE);
     if (myID == MASTER)
@@ -613,13 +606,20 @@ main (int argc, char **argv)
 		
 	      }
 	  }
-	if(EARTH->options->treeinmemory)
+	if(options->treeprint)
 	  {
-	    for(locus=0;locus<EARTH->loci; locus++)
+	    if(EARTH->options->treeinmemory)
 	      {
-		fprintf(EARTH->treefile,"%s", EARTH->treespace[locus]);
+		for(locus=0;locus<EARTH->loci; locus++)
+		  {
+		    fprintf(EARTH->treefile,"%s", EARTH->treespace[locus]);
+		  }
 	      }
+#ifdef NEXUSTREE
+	    FPRINTF(EARTH->treefile,"\nend;\n");
+#endif
 	  }
+
 	// if adaptive heating print a table with the average temperatures
 	//
 	if(options->heating && options->adaptiveheat!=NOTADAPTIVE)
@@ -635,11 +635,17 @@ main (int argc, char **argv)
 	      }
 	    pdf_print_averageheat(universe,options);
 	  }
-#ifdef PRETTY
+	//
+	// print warnings into the PDF and the outfile
+	//
+	print_stored_warnings(EARTH);
+	pdf_print_stored_warnings(EARTH);
+	//
+	//
+	//
 	pdf_print_end_time(&page_height);
 	// write out to PDF file
 	pdf_write_file(options);
-#endif
 	print_finish (EARTH, outfilepos);
 	// closing all files 
 #ifdef MAC
@@ -1828,6 +1834,7 @@ heating_init (world_fmt ** universe, int usize, data_fmt * data,
         create_world (&universe[chain], data->loci);
 	universe[chain]->cold = FALSE;
         init_world (universe[chain], data, options);
+	universe[chain]->heatid = chain;
     }
 }
 
@@ -2132,6 +2139,7 @@ run_increments (world_fmt ** universe,
                 tpool_t * localheating_pool,
                 long increment, long step, long steps)
 {
+  static long treefilepos; /* write position in the treefile */
     long i;
     for (i = 0; i < increment; i++)
     {
@@ -2142,6 +2150,8 @@ run_increments (world_fmt ** universe,
         if (EARTH->likelihood[EARTH->G] > EARTH->maxdatallike)
             EARTH->maxdatallike = EARTH->likelihood[EARTH->G];
     }
+    if (EARTH->options->treeprint != _NONE)
+      print_tree (EARTH, EARTH->G, &treefilepos);
 }
 
 /// \brief run a chain
@@ -3123,12 +3133,22 @@ void reset_bayesmdimfile(world_fmt *world, option_fmt *options)
 #ifdef PARALIO
 	  world->bayesmdimfile = fopen(options->bayesmdimfilename,"r+");
 #else
-	  fflush(world->bayesmdimfile);
-	  world->bayesmdimfile = freopen(options->bayesmdimfilename,"r+", world->bayesmdimfile);
-#endif
+#ifdef ZNZ
+	  znzclose(world->bayesmdimfile);
+	  world->bayesmdimfile = znzopen(options->bayesmdimfilename,"r", options->use_compressed);
 #else
 	  fflush(world->bayesmdimfile);
 	  world->bayesmdimfile = freopen(options->bayesmdimfilename,"r+", world->bayesmdimfile);
+#endif
+#endif
+#else
+#ifdef ZNZ
+	  znzclose(world->bayesmdimfile);
+	  world->bayesmdimfile = znzopen(options->bayesmdimfilename,"r", options->use_compressed);
+#else
+	  fflush(world->bayesmdimfile);
+	  world->bayesmdimfile = freopen(options->bayesmdimfilename,"r+", world->bayesmdimfile);
+#endif
 #endif
 	  read_bayes_fromfile(world->bayesmdimfile,world, options);
 	  for(locus=0;locus<world->loci;locus++)
