@@ -1804,12 +1804,13 @@ eventtime (proposal_fmt * proposal, long pop, vtlist * tentry, char *event)
     MYREAL  denom;
     MYREAL  invdenom;
     MYREAL  rate = proposal->world->options->mu_rates[proposal->world->locus];
+    MYREAL  inheritance = proposal->world->options->inheritance_scalars[proposal->world->locus];
     MYREAL  invrate = 1./ rate;
     MYREAL  mm         = proposal->mig0list[pop] * invrate ;
     //long    design0    = proposal->design0list[pop];
     //could be used to calculate p(gn|go): MYREAL nu;
     lines    = 2.0 * tentry->lineages[pop];
-    denom    = mm + (lines * (1.0 / (proposal->param0[pop]*rate)));
+    denom    = mm + (lines * (1.0 / (inheritance*proposal->param0[pop]*rate)));
     invdenom = 1.0 / denom;
     interval =  (-(LOG (/*nu = */UNIF_RANDUM ())) * invdenom) ;
     //could be used to calculate p(gn|go): proposal->nu += nu; //adds the probabilities (=random numbers);
