@@ -16,7 +16,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 1722 2010-10-09 15:27:25Z beerli $
+$Id: reporter.c 1753 2010-10-29 01:25:04Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -434,12 +434,58 @@ void print_bayes_ess(FILE *file, world_fmt *world, long numparam, int offset,
     {
       pos += sprintf(buffer+pos,"%*.*s(*) averaged over loci.\n", offset, offset, " ");
     }
+  printf("bufsize in print_bayes_ess_buffer: %li\n",pos);
 #ifdef MPI
   if(file==stdout)
-    FPRINTF(file,"[%3i] %s\n", myID, buffer);
+    {
+      if(pos>LINESIZE)
+	{
+	  //printf("bufsize in print_bayes_ess_buffer2: %li / %li\n",pos, numparam*LINESIZE);
+	  fprintf(file,"[%3i] %*.*s\n", myID, (int) LINESIZE, (int) LINESIZE, buffer);
+	  pos -= LINESIZE;
+	  long i=0;
+	  while(pos>LINESIZE)
+	    {
+	      i += LINESIZE;
+	      fprintf(file,"%*.*s\n",(int) LINESIZE, (int) LINESIZE, buffer+i);
+	      pos -= LINESIZE;
+	    }
+	  fprintf(file,"%s\n", buffer+i);
+	}
+      else
+	{
+	  //  printf("bufsize in print_bayes_ess_buffer3: %li\n",pos);
+	fprintf(file,"[%3i] %s\n", myID, buffer);
+	}
+    }
   else
+    {
+      //      printf("bufsize in print_bayes_ess_buffer4: %li\n",pos);
+      if(pos>LINESIZE)
+	{
+	  //printf("bufsize in print_bayes_ess_buffer4.1: %li\n",pos);
+	  fprintf(file,"[%3i] %*.*s\n", myID, (int) LINESIZE, (int) LINESIZE, buffer);
+	  pos -= LINESIZE;
+	  long i=0;
+	  while(pos>LINESIZE)
+	    {
+	      i += LINESIZE;
+	      //  printf("bufsize in print_bayes_ess_buffer4.2 %li: %li\n",pos,i);
+	      fprintf(file,"%*.*s\n", (int) LINESIZE,(int) LINESIZE, buffer+i);
+	      pos -= LINESIZE;
+	    }
+	  //	  printf("bufsize in print_bayes_ess_buffer4.3za: %li %li\n",pos,i);
+	  fprintf(file,"%s\n", buffer+i);
+	}
+      else
+	{
+	  //	  printf("bufsize in print_bayes_ess_buffer5: %li\n",pos);
+	  fprintf(file,"[%3i] %s\n", myID, buffer);
+	}
+    }
+#else
+  fprintf(file,"%s\n", buffer);
 #endif
-    FPRINTF(file,"%s\n", buffer);
   myfree(buffer);
 }
 
